@@ -49,7 +49,7 @@ void dynsec__print_usage(void)
 	printf("Set group for anonymous clients: setAnonymousGroup   <groupname>\n");
 
 	printf("\nClients\n-------\n");
-	printf("Create a new client:         createClient      <username> [-c clientid] [-p password]\n");
+	printf("Create a new client:         createClient      <username> [-i clientid] [-p password]\n");
 	printf("Delete a client:             deleteClient      <username>\n");
 	printf("Set a client password:       setClientPassword <username> [password]\n");
 	printf("Set a client id:             setClientId       <username> [clientid]\n");
