@@ -36,7 +36,7 @@ int handle__auth(struct mosquitto *mosq)
 	mosquitto_property *properties = NULL;
 
 	if(!mosq) return MOSQ_ERR_INVAL;
-	log__printf(mosq, MOSQ_LOG_DEBUG, "Client %s received AUTH", mosq->id);
+	log__printf(mosq, MOSQ_LOG_DEBUG, "Client %s received AUTH", SAFE_PRINT(mosq->id));
 
 	if(mosq->protocol != mosq_p_mqtt5){
 		return MOSQ_ERR_PROTOCOL;
