@@ -4,12 +4,12 @@ Copyright (c) 2009-2020 Roger Light <roger@atchoo.org>
 All rights reserved. This program and the accompanying materials
 are made available under the terms of the Eclipse Public License 2.0
 and Eclipse Distribution License v1.0 which accompany this distribution.
- 
+
 The Eclipse Public License is available at
    https://www.eclipse.org/legal/epl-2.0/
 and the Eclipse Distribution License is available at
   http://www.eclipse.org/org/documents/edl-v10.php.
- 
+
 SPDX-License-Identifier: EPL-2.0 OR BSD-3-Clause
 
 Contributors:
@@ -22,7 +22,6 @@ Contributors:
 /* For initgroups() */
 #  include <unistd.h>
 #  include <grp.h>
-#  include <assert.h>
 #endif
 
 #ifndef WIN32
@@ -160,9 +159,18 @@ static void mosquitto__daemonise(void)
 		exit(1);
 	}
 
-	assert(freopen("/dev/null", "r", stdin));
-	assert(freopen("/dev/null", "w", stdout));
-	assert(freopen("/dev/null", "w", stderr));
+	if(!freopen("/dev/null", "r", stdin)){
+		log__printf(NULL, MOSQ_LOG_ERR, "Error whilst daemonising (%s): %s", "stdin", strerror(errno));
+		exit(1);
+	}
+	if(!freopen("/dev/null", "w", stdout)){
+		log__printf(NULL, MOSQ_LOG_ERR, "Error whilst daemonising (%s): %s", "stdout", strerror(errno));
+		exit(1);
+	}
+	if(!freopen("/dev/null", "w", stderr)){
+		log__printf(NULL, MOSQ_LOG_ERR, "Error whilst daemonising (%s): %s", "stderr", strerror(errno));
+		exit(1);
+	}
 #else
 	log__printf(NULL, MOSQ_LOG_WARNING, "Warning: Can't start in daemon mode in Windows.");
 #endif
@@ -271,10 +279,17 @@ void listeners__add_websockets(struct lws_context *ws_context, mosq_sock_t fd)
 static int listeners__add_local(const char *host, uint16_t port)
 {
 	struct mosquitto__listener *listeners;
+	bool allow_anonymous;
+
 	listeners = db.config->listeners;
+	if(db.config->security_options.allow_anonymous == -1){
+		allow_anonymous = true;
+	}else{
+		allow_anonymous = db.config->security_options.allow_anonymous;
+	}
 
 	listener__set_defaults(&listeners[db.config->listener_count]);
-	listeners[db.config->listener_count].security_options.allow_anonymous = true;
+	listeners[db.config->listener_count].security_options.allow_anonymous = allow_anonymous;
 	listeners[db.config->listener_count].port = port;
 	listeners[db.config->listener_count].host = mosquitto__strdup(host);
 	if(listeners[db.config->listener_count].host == NULL){
@@ -475,7 +490,12 @@ int main(int argc, char *argv[])
 #endif
 
 #ifdef WIN32
-	_setmaxstdio(2048);
+	if(_setmaxstdio(8192) != 8192){
+		/* Old limit was 2048 */
+		if(_setmaxstdio(2048) != 2048){
+			log__printf(NULL, MOSQ_LOG_WARNING, "Warning: Unable to increase maximum allowed connections. This session may be limited to 512 connections.");
+		}
+	}
 #endif
 
 	memset(&db, 0, sizeof(struct mosquitto_db));
@@ -489,6 +509,11 @@ int main(int argc, char *argv[])
 	if(rc != MOSQ_ERR_SUCCESS) return rc;
 	db.config = &config;
 
+	rc = keepalive__init();
+	if(rc){
+		return rc;
+	}
+
 	/* Drop privileges permanently immediately after the config is loaded.
 	 * This requires the user to ensure that all certificates, log locations,
 	 * etc. are accessible my the `mosquitto` or other unprivileged user.
@@ -598,6 +623,7 @@ int main(int argc, char *argv[])
 	mosquitto__free(db.bridges);
 #endif
 	context__free_disused();
+	keepalive__cleanup();
 
 	db__close();
 
