@@ -28,6 +28,7 @@ connect_packet = mosq_test.gen_connect("connect-revoked-test", keepalive=keepali
 
 broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port2, use_conf=True)
 
+ssl_eof = False
 try:
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     context = ssl.create_default_context(ssl.Purpose.SERVER_AUTH, cafile="../ssl/test-root-ca.crt")
@@ -36,7 +37,22 @@ try:
     ssock.settimeout(20)
     try:
         ssock.connect(("localhost", port1))
-        mosq_test.do_send_receive(ssock, connect_packet, "", "connack")
+        try:
+            mosq_test.do_send_receive(ssock, connect_packet, "", "connack")
+        except ssl.SSLEOFError:
+            # Under load, sometimes the broker closes the connection after the
+            # handshake has failed, but before we have chance to send our
+            # payload and so we get an EOF.
+            ssl_eof = True
+        except ssl.SSLError as err:
+            if err.reason == "SSLV3_ALERT_CERTIFICATE_REVOKED":
+                rc = 0
+            elif err.errno == 8 and "EOF occurred" in err.strerror:
+                rc = 0
+            else:
+                broker.terminate()
+                print(err.strerror)
+                raise ValueError(err.errno) from err
     except ssl.SSLError as err:
         if err.errno == 1 and "certificate revoked" in err.strerror:
             rc = 0
@@ -53,6 +69,9 @@ finally:
     broker.terminate()
     broker.wait()
     (stdo, stde) = broker.communicate()
+    if ssl_eof:
+        if "certificate verify failed" in stde.decode('utf-8'):
+            rc = 0
     if rc:
         print(stde.decode('utf-8'))
 
