@@ -47,16 +47,14 @@ try:
     (conn, address) = sock.accept()
     conn.settimeout(10)
 
-    if mosq_test.expect_packet(conn, "connect", connect_packet):
-        conn.send(connack_packet)
-
-        if mosq_test.expect_packet(conn, "subscribe", subscribe_packet):
-            conn.send(suback_packet)
-
-            if mosq_test.expect_packet(conn, "disconnect", disconnect_packet):
-                rc = 0
+    mosq_test.do_receive_send(conn, connect_packet, connack_packet, "connect")
+    mosq_test.do_receive_send(conn, subscribe_packet, suback_packet, "subscribe")
+    mosq_test.expect_packet(conn, "disconnect", disconnect_packet)
+    rc = 0
 
     conn.close()
+except mosq_test.TestError:
+    pass
 finally:
     client.terminate()
     client.wait()
