@@ -22,12 +22,17 @@ int main(int argc, char *argv[])
 	mosquitto_lib_init();
 
 	mosq = mosquitto_new("01-keepalive-pingreq", true, NULL);
+	if(mosq == NULL){
+		return 1;
+	}
 	mosquitto_connect_callback_set(mosq, on_connect);
 
 	rc = mosquitto_connect(mosq, "localhost", port, 5);
+	if(rc != 0) return rc;
 
 	while(run == -1){
-		mosquitto_loop(mosq, -1, 1);
+		rc = mosquitto_loop(mosq, -1, 1);
+		if(rc != 0) break;
 	}
 
 	mosquitto_destroy(mosq);
