@@ -22,6 +22,9 @@ int main(int argc, char *argv[])
 	mosquitto_lib_init();
 
 	mosq = mosquitto_new("01-server-keepalive-pingreq", true, NULL);
+	if(mosq == NULL){
+		return 1;
+	}
 	mosquitto_int_option(mosq, MOSQ_OPT_PROTOCOL_VERSION, MQTT_PROTOCOL_V5);
 	mosquitto_connect_callback_set(mosq, on_connect);
 
