@@ -34,6 +34,9 @@ int main(int argc, char *argv[])
 	mosquitto_lib_init();
 
 	mosq = mosquitto_new("subscribe-qos2-test", true, NULL);
+	if(mosq == NULL){
+		return 1;
+	}
 	mosquitto_connect_callback_set(mosq, on_connect);
 	mosquitto_disconnect_callback_set(mosq, on_disconnect);
 	mosquitto_subscribe_callback_set(mosq, on_subscribe);
@@ -44,6 +47,7 @@ int main(int argc, char *argv[])
 		mosquitto_loop(mosq, -1, 1);
 	}
 
+	mosquitto_destroy(mosq);
 	mosquitto_lib_cleanup();
 	return run;
 }
