@@ -30,6 +30,9 @@ int main(int argc, char *argv[])
 	mosquitto_lib_init();
 
 	mosq = mosquitto_new("08-ssl-connect-crt-auth", true, NULL);
+	if(mosq == NULL){
+		return 1;
+	}
 	mosquitto_tls_set(mosq, "../ssl/test-root-ca.crt", "../ssl/certs", "../ssl/client.crt", "../ssl/client.key", NULL);
 	mosquitto_connect_callback_set(mosq, on_connect);
 	mosquitto_disconnect_callback_set(mosq, on_disconnect);
@@ -39,6 +42,7 @@ int main(int argc, char *argv[])
 	while(run == -1){
 		mosquitto_loop(mosq, -1, 1);
 	}
+	mosquitto_destroy(mosq);
 
 	mosquitto_lib_cleanup();
 	return run;
