@@ -79,6 +79,9 @@ static void int32_prop_read_helper(
 	rc = property__read_all(command, &packet, &properties);
 
 	CU_ASSERT_EQUAL(rc, rc_expected);
+	if(rc != rc_expected){
+		printf("%d / %d\n", rc, rc_expected);
+	}
 	CU_ASSERT_EQUAL(packet.pos, remaining_length);
 	if(properties){
 		CU_ASSERT_EQUAL(properties->identifier, identifier);
@@ -323,6 +326,9 @@ static void varint_prop_read_helper(
 	rc = property__read_all(CMD_PUBLISH, &packet, &properties);
 
 	CU_ASSERT_EQUAL(rc, rc_expected);
+	if(rc != rc_expected){
+		printf("%d / %d\n", rc, rc_expected);
+	}
 	if(properties){
 		CU_ASSERT_EQUAL(properties->identifier, identifier);
 		CU_ASSERT_EQUAL(properties->value.varint, value_expected);
@@ -407,7 +413,7 @@ static void TEST_truncated(void)
 	packet.payload = payload;
 	packet.remaining_length = 0;
 	rc = property__read_all(CMD_CONNECT, &packet, &properties);
-	CU_ASSERT_EQUAL(rc, MOSQ_ERR_PROTOCOL);
+	CU_ASSERT_EQUAL(rc, MOSQ_ERR_MALFORMED_PACKET);
 	CU_ASSERT_PTR_EQUAL(properties, NULL);
 	CU_ASSERT_EQUAL(packet.pos, 0);
 
@@ -418,7 +424,7 @@ static void TEST_truncated(void)
 	packet.payload = payload;
 	packet.remaining_length = 1;
 	rc = property__read_all(CMD_CONNECT, &packet, &properties);
-	CU_ASSERT_EQUAL(rc, MOSQ_ERR_PROTOCOL);
+	CU_ASSERT_EQUAL(rc, MOSQ_ERR_MALFORMED_PACKET);
 	CU_ASSERT_PTR_EQUAL(properties, NULL);
 	CU_ASSERT_EQUAL(packet.pos, 1);
 
@@ -430,7 +436,7 @@ static void TEST_truncated(void)
 	packet.payload = payload;
 	packet.remaining_length = 2;
 	rc = property__read_all(CMD_CONNECT, &packet, &properties);
-	CU_ASSERT_EQUAL(rc, MOSQ_ERR_PROTOCOL);
+	CU_ASSERT_EQUAL(rc, MOSQ_ERR_MALFORMED_PACKET);
 	CU_ASSERT_PTR_EQUAL(properties, NULL);
 	CU_ASSERT_EQUAL(packet.pos, 2);
 }
@@ -1089,7 +1095,7 @@ static void TEST_duplicate_subscription_identifier(void)
 	payload[4] = MQTT_PROP_SUBSCRIPTION_IDENTIFIER;
 	payload[5] = 0x04;
 
-	varint_prop_read_helper(payload, 5, MOSQ_ERR_PROTOCOL, MQTT_PROP_SUBSCRIPTION_IDENTIFIER, 0);
+	varint_prop_read_helper(payload, 5, MOSQ_ERR_MALFORMED_PACKET, MQTT_PROP_SUBSCRIPTION_IDENTIFIER, 0);
 }
 
 /* ========================================================================
@@ -1190,7 +1196,7 @@ static void TEST_bad_subscription_identifier(void)
 	payload[5] = 0xFF;
 	payload[6] = 0x01;
 
-	varint_prop_read_helper(payload, 7, MOSQ_ERR_PROTOCOL, MQTT_PROP_SUBSCRIPTION_IDENTIFIER, 0);
+	varint_prop_read_helper(payload, 7, MOSQ_ERR_MALFORMED_PACKET, MQTT_PROP_SUBSCRIPTION_IDENTIFIER, 0);
 }
 
 /* ========================================================================
